@@ -30,7 +30,7 @@ printGeneral <- function(status,
                          weightEndpoint,
                          Wscheme,
                          ...){
-    
+
     if(!is.null(strata)){
         n.strata <- length(level.strata)
     }else{
@@ -146,13 +146,17 @@ printGeneral <- function(status,
 }
 
 ## * Function printInference
-printInference <- function(method.inference, n.resampling, cpus, seed, ...){
+printInference <- function(method.inference, paired, n.resampling, cpus, seed, ...){
 
     if(method.inference != "none"){
 
         ## method        
         if(attr(method.inference,"ustatistic")){
-            txt.type <- "moments of the U-statistic"
+            if(paired){
+                txt.type <- "variability of the estimate across strata"
+            }else{
+                txt.type <- "moments of the U-statistic"
+            }
         }else if(attr(method.inference,"bootstrap")){
             txt.type <- paste0("non-parametric bootstrap with ",n.resampling," samples")
         }else if(method.inference == "varexact permutation"){
@@ -160,7 +164,7 @@ printInference <- function(method.inference, n.resampling, cpus, seed, ...){
         }else if(attr(method.inference,"permutation")){
             txt.type <- paste0("permutation test with ",n.resampling," permutations")
         }
-        if(!is.na(attr(method.inference,"resampling-strata"))){
+        if(any(!is.na(attr(method.inference,"resampling-strata")))){
             txt.type <- paste0(txt.type, " (stratified by \"",paste(attr(method.inference,"resampling-strata"),sep="\" \""),"\")")
         }
 
