@@ -18,6 +18,7 @@
 #' \code{"Buyse"} to weight proportionally to the number of pairs in the strata,
 #' \code{"CMH"} to weight proportionally to the ratio between the number of pairs in the strata and the number of observations in the strata.
 #' \code{"equal"} to weight equally each strata,
+#' \code{"standardisation"} to recover a marginal comparison,
 #' or \code{"var-netBenefit"} to weight each strata proportionally to the precision of its estimated net benefit (similar syntax for the win ratio: \code{"var-winRatio"})
 #' @param correction.uninf [integer] should a correction be applied to remove the bias due to the presence of uninformative pairs?
 #' 0 indicates no correction, 1 impute the average score of the informative pairs, and 2 performs IPCW.
@@ -112,7 +113,7 @@
 #' Available methods are:
 #' \itemize{
 #'   \item argument \code{method.inference="none"}: only the point estimate is computed which makes the execution of the \code{BuyseTest} faster than with the other methods.
-#'   \item argument \code{method.inference="u-statistic"}: compute the variance of the estimate using a H-projection of order 1 (default option) or 2 (see \code{BuyseTest.options}). The first order is downward biased but consistent. When considering the Gehan scoring rule, no transformation nor correction, the second order is unbiased and equivalent to the variance of the bootstrap distribution. P-values and confidence intervals are then evaluated assuming that the estimates follow a Gaussian distribution.
+#'   \item argument \code{method.inference="u-statistic"}: compute the variance of the estimate using a H-projection of order 1 (default option) or 2 (see \code{BuyseTest.options}). The first order is downward biased but consistent. When considering the Gehan scoring rule, no transformation nor correction, the second order is unbiased and equivalent to the variance of the (stratified) bootstrap distribution. P-values and confidence intervals are then evaluated assuming that the estimates follow a Gaussian distribution. In presence of strata, the weights used to combine estimates across strata are assumed known. This is the case the type of weights used is pre-defined and the covariate distribution is fixed by design as in a blocked randomized trial.
 #' \bold{WARNING}: the current implementation of the H-projection is not valid when using corrections for uninformative pairs (\code{correction.uninf=1}, or \code{correction.uninf=2}).
 #'   \item argument \code{method.inference="permutation"}: perform a permutation test, estimating in each sample the summary statistics (net benefit, win ratio).
 #'   \item argument \code{method.inference="studentized permutation"}: perform a permutation test, estimating in each sample the summary statistics (net benefit, win ratio) and the variance-covariance matrix of the estimate.
@@ -345,7 +346,7 @@ BuyseTest <- function(formula,
     out.name <- c("data","M.endpoint","M.status",
                   "index.C","index.T","weightObs","index.strata",
                   "level.treatment","level.strata", "pool.strata", "method.score", "paired",
-                  "n.strata","n.obs","n.obsStrata","n.obsStrataResampling","cumn.obsStrataResampling","skeletonPeron",
+                  "grid.strata","n.obs","n.obsStrata","n.obsStrataResampling","cumn.obsStrataResampling","skeletonPeron",
                   "scoring.rule", "iidNuisance", "nUTTE.analyzedPeron_M1", "endpoint.UTTE", "status.UTTE", "D.UTTE","index.UTTE","keep.pairScore")
 
     outArgs[out.name] <- initializeData(data = outArgs$data,
@@ -418,7 +419,7 @@ BuyseTest <- function(formula,
 
     ## check number of pairs
     if(option$check){
-        vec.nPair <- (outPoint$count_favorable + outPoint$count_unfavorable + outPoint$count_neutral + outPoint$count_uninf )[,1]
+        vec.nPair <- (outPoint$count_favorable + outPoint$count_unfavorable + outPoint$count_neutral + outPoint$count_uninf)[,1]
         if(any(abs(outPoint$n_pairs - vec.nPair) > 0.01)){
             warning("Incorrect estimation of the number of pairs \n",
                     "Something probably went wrong - contact the package maintainer\n")
@@ -431,8 +432,8 @@ BuyseTest <- function(formula,
         ## needed for inference with bebu
         outPoint$tableScore <- pairScore2dt(outPoint$tableScore,
                                             level.treatment = outArgs$level.treatment,
-                                            level.strata = outArgs$level.strata,
-                                            n.strata = outArgs$n.strata,
+                                            level.strata = rownames(outArgs$grid.strata),
+                                            n.strata = NROW(outArgs$grid.strata),
                                             endpoint = outArgs$endpoint,
                                             threshold = outArgs$threshold,
                                             restriction = outArgs$restriction)
@@ -459,7 +460,7 @@ BuyseTest <- function(formula,
                                                  n.C = length(envirBT$outArgs$index.C),
                                                  n.T = length(envirBT$outArgs$index.T),
                                                  level.strata = outArgs$level.strata,
-                                                 n.strata = outArgs$n.strata,
+                                                 n.strata = NROW(outArgs$grid.strata),
                                                  endpoint = outArgs$endpoint)
 
         outPoint$covariance <- outCovariance$Sigma
@@ -504,7 +505,7 @@ BuyseTest <- function(formula,
         cat("Gather the results in a S4BuyseTest object \n")
     }
     keep.args <- c("index.T", "index.C", "index.strata", "type","endpoint","level.strata","level.treatment","scoring.rule","hierarchical","neutral.as.uninf","add.halfNeutral",
-                   "correction.uninf","method.inference","method.score","strata","threshold","restriction","weightObs","weightEndpoint","pool.strata","n.resampling","paired")
+                   "correction.uninf","method.inference","method.score","strata","threshold","restriction","weightObs","weightEndpoint","pool.strata","grid.strata","n.resampling","paired")
     mycall2 <- setNames(as.list(mycall),names(mycall))
     if(!missing(formula)){
         mycall2$formula <- formula ## change name of the variable into actual value
@@ -535,6 +536,7 @@ BuyseTest <- function(formula,
     if(envir$outArgs$scoring.rule == 0){ ## Gehan
         outSurv <- envir$outArgs$skeletonPeron
     }else{ ## Peron
+
         outSurv <- calcPeron(data = outSample$data,
                              model.tte = envir$outArgs$model.tte,                             
                              method.score = envir$outArgs$method.score,
@@ -552,7 +554,7 @@ BuyseTest <- function(formula,
                              threshold = envir$outArgs$threshold,
                              restriction = envir$outArgs$restriction,
                              level.strata = envir$outArgs$level.strata,
-                             n.strata = envir$outArgs$n.strata,
+                             grid.strata = envir$outArgs$grid.strata,
                              strata = envir$outArgs$strata,
                              precompute = envir$outArgs$precompute,
                              iidNuisance = envir$outArgs$iidNuisance * iid,
@@ -560,7 +562,7 @@ BuyseTest <- function(formula,
                              fitter = envir$outArgs$fitter.model.tte,
                              efron = envir$outArgs$scoring.rule==2,
                              args = envir$outArgs$args.model.tte)
-        
+
         index.test <- which(envir$outArgs$method.score == "SurvPeron")
         if(!grepl("permutation|bootstrap",method.inference) && envir$outArgs$correction.uninf>0 && length(index.test)>0 && all(is.na(envir$outArgs$restriction))){
             maxLastSurv <- setNames(sapply(outSurv$lastSurv[index.test],max),envir$outArgs$endpoint[index.test])[!duplicated(envir$outArgs$endpoint[index.test])]
@@ -615,7 +617,7 @@ BuyseTest <- function(formula,
                                  op = envir$outArgs$operator,
                                  D = envir$outArgs$D,
                                  D_UTTE = envir$outArgs$D.UTTE,
-                                 n_strata = envir$outArgs$n.strata,
+                                 grid_strata = envir$outArgs$grid.strata,
                                  nUTTE_analyzedPeron_M1 = envir$outArgs$nUTTE.analyzedPeron_M1,
                                  index_endpoint = envir$outArgs$index.endpoint,
                                  index_status = envir$outArgs$index.status,
@@ -653,7 +655,8 @@ BuyseTest <- function(formula,
         ## index <- 5
         ## resBT$Delta[,index]
         ## sum(resBT$delta[,,index][,1] * resBT$weightStrata)
-        return(list(delta = resBT$delta,
+        return(list(n = rbind(T = lengths(outSample$ls.indexT), C = lengths(outSample$ls.indexC)),
+                    delta = resBT$delta,
                     Delta = resBT$Delta,
                     weightStrata = resBT$weightStrata,
                     covariance = resBT$covariance))
@@ -664,12 +667,13 @@ BuyseTest <- function(formula,
 calcSample <- function(envir, method.inference){
 
     ## ** initialization
+    nlevel.strata <- length(envir$outArgs$level.strata)
     out <- list(## rows in M.endpoint/M.status corresponding to observations from the control/treatment group (not unique when boostraping)
-        ls.indexC = vector(mode = "list", length = envir$outArgs$n.strata), 
-        ls.indexT = vector(mode = "list", length = envir$outArgs$n.strata),
+        ls.indexC = vector(mode = "list", length = nlevel.strata), 
+        ls.indexT = vector(mode = "list", length = nlevel.strata),
         ## identifier for each observation from the control/treatment group (unique even when boostrap)
-        ls.posC = vector(mode = "list", length = envir$outArgs$n.strata),
-        ls.posT = vector(mode = "list", length = envir$outArgs$n.strata),
+        ls.posC = vector(mode = "list", length = nlevel.strata),
+        ls.posT = vector(mode = "list", length = nlevel.strata),
         ## dataset
         data = data.table::data.table()
     )
@@ -677,11 +681,11 @@ calcSample <- function(envir, method.inference){
     if(method.inference %in% c("none","u statistic")){
 
         ## ** no resampling
-        if(envir$outArgs$n.strata==1){        
+        if(nlevel.strata==1){        
             out$ls.indexC[[1]] <- envir$outArgs$index.C - 1
             out$ls.indexT[[1]] <- envir$outArgs$index.T - 1
         }else{        
-            for(iStrata in 1:envir$outArgs$n.strata){ ## iStrata <- 1  
+            for(iStrata in 1:nlevel.strata){ ## iStrata <- 1  
                 out$ls.indexC[[iStrata]] <- intersect(envir$outArgs$index.C, envir$outArgs$index.strata[[iStrata]]) - 1
                 out$ls.indexT[[iStrata]] <- intersect(envir$outArgs$index.T, envir$outArgs$index.strata[[iStrata]]) - 1
             }
@@ -703,11 +707,11 @@ calcSample <- function(envir, method.inference){
             index.resampling <- c(index.resampling,
                                   envir$outArgs$cumn.obsStrataResampling[iSR] + sample.int(envir$outArgs$n.obsStrataResampling[iSR], replace = attr(method.inference, "bootstrap")))
         }
-        
+
         ## ** reconstruct groups
         ## index: index of the new observations in the old dataset by treatment group
         ## pos: unique identifier for each observation
-        if(envir$outArgs$n.strata==1){ ## no strata
+        if(nlevel.strata==1){ ## no strata
             
             if(grepl("permutation",method.inference)){
                 out$ls.indexC[[1]] <- which(index.resampling %in% envir$outArgs$index.C) - 1
@@ -731,8 +735,8 @@ calcSample <- function(envir, method.inference){
                 index.C <- which(index.resampling %in% envir$outArgs$index.C)
                 index.T <- which(index.resampling %in% envir$outArgs$index.T)
             }
-            
-            for(iStrata in 1:envir$outArgs$n.strata){ ## iStrata <- 1  
+
+            for(iStrata in 1:nlevel.strata){ ## iStrata <- 1  
                 ## index of the new observations in the old dataset by treatment group
                 if(grepl("permutation",method.inference)){
                     out$ls.indexC[[iStrata]] <- intersect(index.C, envir$outArgs$index.strata[[iStrata]]) - 1
@@ -748,7 +752,7 @@ calcSample <- function(envir, method.inference){
                 ## check that each group has at least one observation
                 if(length(out$ls.indexC[[iStrata]])==0 || length(out$ls.indexT[[iStrata]])==0){return(NULL)} 
             }
-            
+
         }
 
         ## ** rebuild dataset
@@ -763,6 +767,17 @@ calcSample <- function(envir, method.inference){
                                                    envir$outArgs$M.endpoint,
                                                    envir$outArgs$M.status)[index.resampling]
             }
+            ## re-create original strata variables                
+            if(nlevel.strata>1 && length(envir$outArgs$strata)==1 && envir$outArgs$strata %in% names(out$data) == FALSE){ 
+                out$data[[envir$outArgs$strata]] <- envir$outArgs$level.strata[out$data[["..strata.."]]]
+                if(is.factor(envir$outArgs$data[[envir$outArgs$strata]])){
+                    out$data[[envir$outArgs$strata]] <- factor(out$data[[envir$outArgs$strata]], levels = envir$outArgs$level.strata)
+                }
+            }else if(nlevel.strata>1 && length(envir$outArgs$strata)>1 && all(envir$outArgs$strata %in% names(out$data) == FALSE)){
+                grid.strata <- unique(envir$outArgs$data[,.SD,.SDcols = c("..strata..",envir$outArgs$strata)])
+
+                out$data <- cbind(out$data,grid.strata[match(out$data[["..strata.."]], grid.strata[["..strata.."]]),.SD,.SDcols = envir$outArgs$strata] )
+            }
         }
 
     }
