@@ -4,7 +4,7 @@
 ## Created: maj 19 2018 (23:37) 
 ## Version: 
 ##           By: Brice Ozenne
-##     Update #: 1230
+##     Update #: 1264
 ##----------------------------------------------------------------------
 ## 
 ### Commentary: 
@@ -192,6 +192,11 @@ setMethod(f = "confint",
                                  refuse.NULL = FALSE,
                                  method = "confint[S4BuyseTest]")
               }
+              if(attr(object@weightStrata,"type")=="standardization" && attr(method.inference,"ustatistic") && any(strata %in% level.strata)){
+                  ## note: error message for studentized method is triggered later (end of method.ci checks)
+                  stop("Cannot output the strata-specific uncertainty based on the H-decomposition when using standardization. \n",
+                       "Consider using a resampling method by specifying the argument \'method.inference\' when calling the \"BuyseTest\" function. \n")
+              }
               if(attr(slot(object,"scoring.rule"), "test.paired") && any(level.strata %in% strata)){
                   stop("Cannot output p-values or confidence intervals for stratified statistics with paired data. \n")
               }
@@ -332,7 +337,7 @@ setMethod(f = "confint",
               if(!is.null(cluster) && any(object@weightObs!=1)){
                   stop("Cannot handle clustered observations when observations are weighted. \n")
               }
-              
+
               ## ** extract estimate
               all.endpoint <- names(object@endpoint)
               DeltaW <- coef(object, endpoint = endpoint, statistic = statistic, strata = strata, cumulative = cumulative, resampling = FALSE, simplify = FALSE)
@@ -374,13 +379,17 @@ setMethod(f = "confint",
                           warning("Inference will be performed using a first order H projection. \n")
                       }
                       ls.Delta.iid <- getIid(object, statistic = statistic, cumulative = cumulative, endpoint = endpoint, strata = strata, cluster = cluster, simplify = FALSE)
-                      if(length(strata)==1 || all(strata=="global")){
-                          Delta.iid <- ls.Delta.iid[["global"]][,names(Delta),drop=FALSE]
+                      if(length(strata) == 1 && all(strata=="global")){
+                          Delta.iid <- ls.Delta.iid$global[,names(Delta),drop=FALSE]
                       }else{
                           for(iS in 1:length(strata)){ ## iS <- 1
                               colnames(ls.Delta.iid[[iS]]) <- paste(colnames(ls.Delta.iid[[iS]]), strata[iS], sep = sep)
                           }
-                          Delta.iid <- do.call(cbind,ls.Delta.iid)[,names(Delta),drop=FALSE]
+                          if(length(strata)==1){
+                              Delta.iid <- ls.Delta.iid[[1]][,names(Delta),drop=FALSE]
+                          }else{
+                              Delta.iid <- do.call(cbind,ls.Delta.iid)[,names(Delta),drop=FALSE]
+                          }
                       }
                       if(is.null(cluster) && any(object@weightObs!=1)){
                           Delta.iid <- .colMultiply_cpp(Delta.iid, sqrt(object@weightObs))
