@@ -362,22 +362,26 @@ setMethod(f = "summary",
                   if(method.inference != "none"){
                       cat(" - confidence level: ",1-alpha," \n", sep = "")
 
-                  if(attr(method.inference,"permutation")){
-                      txt.method <- "permutation test"
-                  }else if(attr(method.inference,"bootstrap")){
-                      txt.method <- "bootstrap resampling"
-                  }else if(attr(method.inference,"ustatistic")){
-                      test.model.tte <- all(unlist(lapply(object@iidNuisance,dim))==0)
-                      txt.method <- paste0("H-projection of order ",attr(method.inference,"hprojection"))
-                      if(transform != "id"){
-                          txt.method <- paste0(txt.method," after ",transform," transformation \n")
-                      }else{
-                          txt.method <- paste0(txt.method," \n")
+                      if(attr(method.inference,"permutation")){
+                          txt.method <- "permutation test"
+                      }else if(attr(method.inference,"bootstrap")){
+                          txt.method <- "bootstrap resampling"
+                      }else if(attr(method.inference,"ustatistic")){
+                          test.model.tte <- all(unlist(lapply(object@iidNuisance,dim))==0)
+                          if(attr(object@scoring.rule,"test.paired")){
+                              txt.method <- paste0("variability of the estimate across strata")
+                          }else{
+                              txt.method <- paste0("H-projection of order ",attr(method.inference,"hprojection"))
+                          }
+                          if(transform != "id"){
+                              txt.method <- paste0(txt.method," after ",transform," transformation \n")
+                          }else{
+                              txt.method <- paste0(txt.method," \n")
+                          }
+                          if(test.model.tte && (scoring.rule == "Peron" || object@correction.uninf > 0)){
+                              txt.method <- paste0(txt.method,"                     (ignoring the uncertainty of the nuisance parameters)")
+                          }
                       }
-                      if(test.model.tte && (scoring.rule == "Peron" || object@correction.uninf > 0)){
-                          txt.method <- paste0(txt.method,"                     (ignoring the uncertainty of the nuisance parameters)")
-                      }
-                  }
 
                   if(attr(method.inference,"permutation") || attr(method.inference,"bootstrap") ){
                       
